; Author:      Roy Klein Gebbinck (www.b-k-g.nl)
; Version:     20171213: First version.
; Created for: https://forum.bricsys.com/discussion/32575/user-profile-manager-settings


; BricsCAD V17 or higher is required (new getcfg and setcfg):
(if (> 17 (atoi (getvar '_vernum)))
  (progn
    (princ "\nImportSettings requires BricsCAD V17 or higher ")
    (exit)
  )
)

; Fields in settings file:
; 0    1         2         3       4             5             6      7
; Name,Save mode,Save type,Restype,Default value,Current value,Status,Title
(defun ImportSettings (idx / failLst fnm lst) ; Idx: 4 or 5.
  (if
    (and
      (setq fnm (getfiled "Select Settings File" "" "csv" 4))
      (setq lst (cddr (vle-file->list fnm nil))) ; Remove headers and empty line.
      (setq lst (mapcar '(lambda (str) (vle-string-split "," str)) lst))
      (=
        1
        (vle-alert
          "ImportSettings"
          (strcat
            "\nThis program will import ALL non-dwg related settings from:"
            "\n" fnm
            "\n"
            "\nAre you sure you want to continue?"
          )
          305
        )
      )
    )
    (progn
      (setq failLst
        (vl-remove
          nil
          (mapcar
            '(lambda (sub)
              (if
                (and
                  (getcfg (vle-nth0 sub))                           ; Check if the setting exists.
                  (not (vl-position (vle-nth1 sub) '("drw" "not"))) ; Skip settings that are drawing-related or not saved.
                  (/= (vle-nth6 sub) "read only")                   ; Skip read-only settings.
                  (/= (nth idx sub) "")                             ; Skip settings that do not have a (default) value.
                  (not (setcfg (vle-nth0 sub) (nth idx sub)))
                )
                (vle-nth0 sub)
              )
            )
            lst
          )
        )
      )
      (if failLst
        (progn
          (princ "\n****************************************************** ")
          (princ "\nThe following setting(s) could not be changed: ")
          (foreach str failLst (princ (strcat "\n  " str)))
          (princ "\nYou can try running the program again ")
          (princ "\n****************************************************** ")
        )
      )
      (princ "\nDone ")
    )
  )
  (princ)
)

(defun c:ImportSettingsDefaultValues ()
  (ImportSettings 4)
)

(defun c:ImportSettingsUserValues ()
  (ImportSettings 5)
)

(princ "\nUse ImportSettingsUserValues or ImportSettingsDefaultValues ")
(princ)
